fhirpack.custom.load package — fhirpack 0.0.2b0 documentation

# fhirpack.custom.load package

## Submodules

## fhirpack.custom.load.base module

class fhirpack.custom.load.base.PluginBaseLoaderMixin

  Bases: `object`

  __dict__ = mappingproxy({'__module__': 'fhirpack.custom.load.base', 'unimplementedPluginBaseLoaderMethod': <function PluginBaseLoaderMixin.unimplementedPluginBaseLoaderMethod>, '__dict__': <attribute '__dict__' of 'PluginBaseLoaderMixin' objects>, '__weakref__': <attribute '__weakref__' of 'PluginBaseLoaderMixin' objects>, '__doc__': None, '__annotations__': {}})
  __doc__ = None
  __module__ = 'fhirpack.custom.load.base'
  __weakref__

    list of weak references to the object (if defined)

  unimplementedPluginBaseLoaderMethod(input: Optional[Union[list[str], list[fhirpy.lib.SyncFHIRReference], list[fhirpy.lib.SyncFHIRResource]]] = None, params: Optional[dict] = None, ignoreFrame: bool = False)

## fhirpack.custom.load.sample module

class fhirpack.custom.load.sample.PluginSampleLoaderMixin

  Bases: `object`

  __dict__ = mappingproxy({'__module__': 'fhirpack.custom.load.sample', 'unimplementedPluginSampleLoaderMethod': <function PluginSampleLoaderMixin.unimplementedPluginSampleLoaderMethod>, '__dict__': <attribute '__dict__' of 'PluginSampleLoaderMixin' objects>, '__weakref__': <attribute '__weakref__' of 'PluginSampleLoaderMixin' objects>, '__doc__': None, '__annotations__': {}})
  __doc__ = None
  __module__ = 'fhirpack.custom.load.sample'
  __weakref__

    list of weak references to the object (if defined)

  unimplementedPluginSampleLoaderMethod(input: Optional[Union[list[str], list[fhirpy.lib.SyncFHIRReference], list[fhirpy.lib.SyncFHIRResource]]] = None, params: Optional[dict] = None, ignoreFrame: bool = False)

## Module contents

class fhirpack.custom.load.PluginLoaderMixin

  Bases: `PluginBaseLoaderMixin`, `PluginSampleLoaderMixin`

  __doc__ = None
  __module__ = 'fhirpack.custom.load'